==> owncloud-10.0.3.tgz: owncloud/apps/federatedfilesharing/l10n/fi_FI.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federoitu jakaminen",
    "Invalid Federated Cloud ID" : "Virheellinen federoidun pilven tunniste",
    "Sharing %s failed, because this item is already shared with %s" : "Kohteen %s jakaminen epäonnistui, koska kohde on jo jaettu käyttäjän %s kanssa",
    "Not allowed to create a federated share with the same user" : "Saman käyttäjän kanssa ei ole sallittua luoda federoitua jakoa",
    "File is already shared with %s" : "Tiedosto on jo jaettu kohteen %s kanssa",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Kohteen %s jakaminen epäonnistui, kohdetta %s ei löytynyt. Kenties palvelin ei ole juuri nyt tavoitettavissa.",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta, katso %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "Open documentation" : "Avaa dokumentaatio",
    "Allow users on this server to send shares to other servers" : "Salli tämän palvelimen käyttäjien lähettää jakoja muille palvelimille",
    "Allow users on this server to receive shares from other servers" : "Salli tämän palvelimen käyttäjien vastaanottaa jakoja muilta palvelimilta",
    "Federated Cloud" : "Federoitu pilvi",
    "Your Federated Cloud ID:" : "Federoidun pilvesi tunniste:",
    "Share it:" : "Jaa se:",
    "Add to your website" : "Lisää verkkosivuillesi",
    "Share with me via ownCloud" : "Jaa kanssani ownCloudin kautta",
    "HTML Code:" : "HTML-koodi:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/fi_FI.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federoitu jakaminen",
    "Invalid Federated Cloud ID" : "Virheellinen federoidun pilven tunniste",
    "Sharing %s failed, because this item is already shared with %s" : "Kohteen %s jakaminen epäonnistui, koska kohde on jo jaettu käyttäjän %s kanssa",
    "Not allowed to create a federated share with the same user" : "Saman käyttäjän kanssa ei ole sallittua luoda federoitua jakoa",
    "File is already shared with %s" : "Tiedosto on jo jaettu kohteen %s kanssa",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Kohteen %s jakaminen epäonnistui, kohdetta %s ei löytynyt. Kenties palvelin ei ole juuri nyt tavoitettavissa.",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta, katso %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Jaa kanssani käyttäen #ownCloud ja federoitua pilvitunnistetta",
    "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
    "Open documentation" : "Avaa dokumentaatio",
    "Allow users on this server to send shares to other servers" : "Salli tämän palvelimen käyttäjien lähettää jakoja muille palvelimille",
    "Allow users on this server to receive shares from other servers" : "Salli tämän palvelimen käyttäjien vastaanottaa jakoja muilta palvelimilta",
    "Federated Cloud" : "Federoitu pilvi",
    "Your Federated Cloud ID:" : "Federoidun pilvesi tunniste:",
    "Share it:" : "Jaa se:",
    "Add to your website" : "Lisää verkkosivuillesi",
    "Share with me via ownCloud" : "Jaa kanssani ownCloudin kautta",
    "HTML Code:" : "HTML-koodi:",
    "Add to your ownCloud" : "Lisää ownCloudiisi"
},
"nplurals=2; plural=(n != 1);");
